@@ -23,9 +23,10 @@ class NeoNatsClient(NATS):
             f"nats://{self.npq_host}:{self.npq_port}",
             user=self.npq_user,
             password=self.npq_pass,
-            io_loop=loop,
+            loop=loop,
         )
-        self.logger.info(f"Connected to nats://{self.npq_host}:{self.npq_port}")
+        self.logger.info(
+            f"Connected to nats://{self.npq_host}:{self.npq_port}")
 
     async def process(self, queue, processor):
         async def process_handler(msg):
